.dropdown-menu.is-opened-top{bottom:none!important}.err__msg[data-v-bef81972],.err__title[data-v-bef81972],body{margin:0}#app{font-family:Avenir,Helvetica,Arial,sans-serif;-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;color:#2c3e50}