(function(e){function t(t){for(var n,o,l=t[0],s=t[1],b=t[2],u=0,d=[];u<l.length;u++)o=l[u],Object.prototype.hasOwnProperty.call(r,o)&&r[o]&&d.push(r[o][0]),r[o]=0;for(n in s)Object.prototype.hasOwnProperty.call(s,n)&&(e[n]=s[n]);i&&i(t);while(d.length)d.shift()();return a.push.apply(a,b||[]),c()}function c(){for(var e,t=0;t<a.length;t++){for(var c=a[t],n=!0,l=1;l<c.length;l++){var s=c[l];0!==r[s]&&(n=!1)}n&&(a.splice(t--,1),e=o(o.s=c[0]))}return e}var n={},r={app:0},a=[];function o(t){if(n[t])return n[t].exports;var c=n[t]={i:t,l:!1,exports:{}};return e[t].call(c.exports,c,c.exports,o),c.l=!0,c.exports}o.m=e,o.c=n,o.d=function(e,t,c){o.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:c})},o.r=function(e){"undefined"!==typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},o.t=function(e,t){if(1&t&&(e=o(e)),8&t)return e;if(4&t&&"object"===typeof e&&e&&e.__esModule)return e;var c=Object.create(null);if(o.r(c),Object.defineProperty(c,"default",{enumerable:!0,value:e}),2&t&&"string"!=typeof e)for(var n in e)o.d(c,n,function(t){return e[t]}.bind(null,n));return c},o.n=function(e){var t=e&&e.__esModule?function(){return e["default"]}:function(){return e};return o.d(t,"a",t),t},o.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},o.p="";var l=window["webpackJsonp"]=window["webpackJsonp"]||[],s=l.push.bind(l);l.push=t,l=l.slice();for(var b=0;b<l.length;b++)t(l[b]);var i=s;a.push([0,"chunk-vendors"]),c()})({0:function(e,t,c){e.exports=c("cd49")},"12b4":function(e,t,c){"use strict";c("7d8e")},"44dc":function(e,t,c){"use strict";c("a61a")},"7d8e":function(e,t,c){},a61a:function(e,t,c){},cd49:function(e,t,c){"use strict";c.r(t);var n=c("7a23");const r={id:"app"};function a(e,t,c,a,o,l){const s=Object(n["E"])("Streamfy"),b=Object(n["E"])("WithStreamlitConnection");return Object(n["y"])(),Object(n["i"])("div",r,[Object(n["m"])(b,null,{default:Object(n["P"])(({args:e})=>[Object(n["m"])(s,{args:e},null,8,["args"])]),_:1})])}const o=["onClick"],l=["src"];function s(e,t,c,r,a,s){const b=Object(n["E"])("b-breadcrumb-item"),i=Object(n["E"])("b-breadcrumb"),u=Object(n["E"])("b-button"),d=Object(n["E"])("b-carousel-item"),j=Object(n["E"])("b-carousel-list"),O=Object(n["E"])("b-carousel"),f=Object(n["E"])("b-taginput"),m=Object(n["E"])("b-table"),p=Object(n["E"])("b-field");return Object(n["y"])(),Object(n["i"])("span",null,[Object(n["m"])(p,{ref:"field",label:e.label},{default:Object(n["P"])(()=>["breadcrumb"==c.args.component&&void 0!=c.args.items?(Object(n["y"])(),Object(n["g"])(i,{key:0},{default:Object(n["P"])(()=>[(Object(n["y"])(!0),Object(n["i"])(n["b"],null,Object(n["C"])(c.args.items,(e,t)=>(Object(n["y"])(),Object(n["g"])(b,Object(n["q"])({key:t},e,{onClick:t=>s.click(e)}),{default:Object(n["P"])(()=>[Object(n["l"])(Object(n["H"])(e.text),1)]),_:2},1040,["onClick"]))),128))]),_:1})):"button"==c.args.component?(Object(n["y"])(),Object(n["g"])(u,Object(n["q"])({key:1},c.args,{onClick:t[0]||(t[0]=e=>s.click(c.args))}),{default:Object(n["P"])(()=>[Object(n["l"])(Object(n["H"])(c.args.text),1)]),_:1},16)):"carousel"==c.args.component?(Object(n["y"])(),Object(n["g"])(O,Object(n["s"])(Object(n["q"])({key:2},c.args)),{list:Object(n["P"])(e=>[Object(n["m"])(j,{modelValue:e.active,"onUpdate:modelValue":t=>e.active=t,data:c.args.items,onSwitch:t=>e.switch(t,!1),"as-indicator":""},null,8,["modelValue","onUpdate:modelValue","data","onSwitch"])]),default:Object(n["P"])(()=>[(Object(n["y"])(!0),Object(n["i"])(n["b"],null,Object(n["C"])(c.args.items,(e,t)=>(Object(n["y"])(),Object(n["g"])(d,{key:t},{default:Object(n["P"])(()=>[Object(n["j"])("a",{class:"image",onClick:t=>s.click(e)},[Object(n["j"])("img",{src:e},null,8,l)],8,o)]),_:2},1024))),128))]),_:1},16)):"taginput"==c.args.component?(Object(n["y"])(),Object(n["g"])(f,Object(n["q"])({key:3,modelValue:a.result,"onUpdate:modelValue":t[1]||(t[1]=e=>a.result=e)},c.args,{onFocus:s.focused,onBlur:s.blured}),null,16,["modelValue","onFocus","onBlur"])):"table"==c.args.component?(Object(n["y"])(),Object(n["g"])(m,Object(n["q"])({key:4},c.args,{"mobile-cards":void 0!=c.args["has_mobile_cards"]&&c.args["has_mobile_cards"]}),null,16,["mobile-cards"])):Object(n["h"])("",!0)]),_:1},8,["label"])])}var b=c("d092");function i(){Object(n["v"])(()=>{b["a"].setFrameHeight()}),Object(n["x"])(()=>{b["a"].setFrameHeight()})}
/**
 * @license
 * Copyright 2018-2020 Streamlit Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */var u={name:"Streamfy",props:["args"],data(){return setTimeout(()=>b["a"].setFrameHeight(),1e3),{result:[],jdata:void 0}},methods:{focused(){if(this.field){const e=this.field.$el.querySelector(".dropdown-menu");e.style.bottom="auto"}b["a"].setFrameHeight(300),setTimeout(()=>b["a"].setFrameHeight(),200)},blured(){setTimeout(()=>b["a"].setFrameHeight(),200)},click(e){this.result=e}},watch:{result(){var e;null!==(e=this.result)&&void 0!==e&&e.length?b["a"].setComponentValue([...this.result]):"object"==typeof this.result?b["a"].setComponentValue(Object.assign({},this.result)):b["a"].setComponentValue(this.result)}},setup(){i();const e=Object(n["B"])(null);return{field:e}}},d=(c("12b4"),c("6b0d")),j=c.n(d);const O=j()(u,[["render",s]]);var f=O;const m=e=>(Object(n["A"])("data-v-bef81972"),e=e(),Object(n["z"])(),e),p={key:0},g=m(()=>Object(n["j"])("h1",{class:"err__title"},"Component Error",-1)),v={class:"err__msg"};function y(e,t,c,r,a,o){return Object(n["y"])(),Object(n["i"])("div",null,[""!=e.componentError?(Object(n["y"])(),Object(n["i"])("div",p,[g,Object(n["j"])("div",v,"Message: "+Object(n["H"])(e.componentError),1)])):null!=e.renderData?Object(n["D"])(e.$slots,"default",{key:1,args:e.renderData.args,disabled:e.renderData.disabled},void 0,!0):Object(n["h"])("",!0)])}var h=Object(n["n"])({name:"WithStreamlitConnection",setup(){const e=Object(n["B"])(void 0),t=Object(n["B"])(""),c=c=>{const n=c;e.value=n.detail,t.value=""};return Object(n["v"])(()=>{b["a"].events.addEventListener(b["a"].RENDER_EVENT,c),b["a"].setComponentReady()}),Object(n["x"])(()=>{""!=t.value&&b["a"].setFrameHeight()}),Object(n["w"])(()=>{b["a"].events.removeEventListener(b["a"].RENDER_EVENT,c)}),Object(n["u"])(e=>{t.value=String(e)}),{renderData:e,componentError:t}}});c("44dc");const E=j()(h,[["render",y],["__scopeId","data-v-bef81972"]]);var _=E,k=Object(n["n"])({name:"App",components:{Streamfy:f,WithStreamlitConnection:_}});c("df56");const w=j()(k,[["render",a]]);var C=w,P=c("9f7e");c("d120");const S=Object(n["f"])(C);S.use(P["a"]),S.mount("#app")},df56:function(e,t,c){"use strict";c("dfc8")},dfc8:function(e,t,c){}});
//# sourceMappingURL=app.9ee6266c.js.map